@@ -61,7 +61,9 @@ class SendGrid(object):
                 "list": "/api/newsletter/category/list.json",
                 "add": "/api/newsletter/category/add.json"},
             "stats": {
-                "get": "/apiv2/customer.stats.json"}
+                "get": "/apiv2/customer.stats.json"},
+            "unsubscribes": {
+                "get": "/api/unsubscribes.get.json"}
         }
 
     def build_params(self, d=None):
@@ -251,6 +253,9 @@ class SendGrid(object):
         '''other fields can be days, start_date, end_date'''
         return self.call('stats', 'get', dict(category=category, user=user))
 
+    def get_unsubscribes(self):
+        return self.call('unsubscribes', 'get')
+
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
                         newsletter_name,  # existing newsletter_name to be cloned
